]> AND Private Git Repository - loba.git/blobdiff - process.h
Logo AND Algorithmique Numérique Distribuée

Private GIT Repository
Partially revert "modif simple"
[loba.git] / process.h
index fb1fe3f377f9626a5af4fc0bc204e78c5691c5a9..1374bf4b9458e4f85601363651c44cb057fd4e9b 100644 (file)
--- a/process.h
+++ b/process.h
@@ -28,7 +28,7 @@ public:
     virtual ~process();
 
     double get_comp() const                { return comp; }
-    double get_load() const                { return load; }
+    double get_real_load() const           { return real_load; }
 
     int run();
 
@@ -39,8 +39,10 @@ protected:
     pneigh_type pneigh;         // list of pointers to neighbors that
                                 // we are free to reorder
 
-    // Returns the sum of "to_send" for all neighbors.
-    double sum_of_to_send() const;
+    // Get and set current load, which may be real load, or expected
+    // load if opt::bookkeeping is true.
+    double get_load() const;
+    void set_load(double load);
 
     // Calls neighbor::print(verbose, logp, cat) for each member of neigh.
     void print_loads(bool verbose = false,
@@ -77,14 +79,12 @@ private:
 
     double prev_load_broadcast; // used to ensure that we do not send
                                 // a same information messages
-    double load;                // current load
+    double real_load;           // current load
     double expected_load;       // expected load in bookkeeping mode
 
-    double& lb_load() { return opt::bookkeeping ? expected_load : load; }
-
     // The load balancing algorithm comes here...
     // Parameter "my_load" is the load to take into account for myself
// (may be load or expected load).
     // Returns the total load sent to neighbors.
     virtual double load_balance(double my_load);
 
@@ -94,7 +94,7 @@ private:
     // Send procedures, with helpers for bookkeeping mode or not
     void send1_no_bookkeeping(neighbor& nb);
     void send1_bookkeeping(neighbor& nb);
-    void send();
+    void send_all();
 
     // Returns true if there remains neighbors to listen for
     bool may_receive() { return ctrl_close_pending || data_close_pending; }
@@ -110,6 +110,24 @@ private:
     void finalize();
 };
 
+inline
+double process::get_load() const
+{
+    if (opt::bookkeeping)
+        return expected_load;
+    else
+        return real_load;
+}
+
+inline
+void process::set_load(double load)
+{
+    if (opt::bookkeeping)
+        expected_load = load;
+    else
+        real_load = load;
+}
+
 #endif // !PROCESS_H
 
 // Local variables:
@@ -77,14 +79,12 @@ private:
     // The load balancing algorithm comes here...
     // Parameter "my_load" is the load to take into account for myself
-    // (may be load or expected load).
+    // (may be real load or expected load).
     // Returns the total load sent to neighbors.
     virtual double load_balance(double my_load);